# Muffins

A plugin for [PyPlanet](https://pypla.net/).

The Muffins plugin allows you to bake, give, and eat muffins.

## Commands

|Command|Description|
|---|---|
| //muffin <login or nickname> | Bakes a brand new muffin and gives it to the player specified by login or nickname. Only available to admins. |
| /muffin eat | Eat one of your muffins. Available to all players |
| /muffin brag | Show off one of your rarest muffins. Available to all players |
| /muffin give <login or nickname> | Give one of your muffins to the player specified by login or nickname. Available to all players. |
